#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'scriptpluginwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCRIPTPLUGINWIDGET_H
#define UI_SCRIPTPLUGINWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ScriptPluginWidget
{
public:
    QVBoxLayout *verticalLayout_5;
    QSplitter *splitter;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QLabel *labelDescVariables;
    QHBoxLayout *horizontalLayout;
    QTreeWidget *listVariables;
    QVBoxLayout *verticalLayout;
    QPushButton *buttonAdd;
    QPushButton *buttonRemove;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_4;
    QLabel *labelDescDef;
    QHBoxLayout *horizontalLayout_2;
    QTextEdit *textCode;
    QVBoxLayout *verticalLayout_3;
    QPushButton *buttonSave;
    QPushButton *buttonLoad;
    QPushButton *buttonInsert;
    QSpacerItem *verticalSpacer_2;
    QPushButton *buttonTest;

    void setupUi(QWidget *ScriptPluginWidget)
    {
        if (ScriptPluginWidget->objectName().isEmpty())
            ScriptPluginWidget->setObjectName(QString::fromUtf8("ScriptPluginWidget"));
        ScriptPluginWidget->resize(534, 552);
        verticalLayout_5 = new QVBoxLayout(ScriptPluginWidget);
        verticalLayout_5->setObjectName(QString::fromUtf8("verticalLayout_5"));
        splitter = new QSplitter(ScriptPluginWidget);
        splitter->setObjectName(QString::fromUtf8("splitter"));
        splitter->setOrientation(Qt::Vertical);
        splitter->setChildrenCollapsible(false);
        groupBox = new QGroupBox(splitter);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        labelDescVariables = new QLabel(groupBox);
        labelDescVariables->setObjectName(QString::fromUtf8("labelDescVariables"));

        verticalLayout_2->addWidget(labelDescVariables);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        listVariables = new QTreeWidget(groupBox);
        listVariables->setObjectName(QString::fromUtf8("listVariables"));
        listVariables->setEditTriggers(QAbstractItemView::NoEditTriggers);
        listVariables->setAlternatingRowColors(true);
        listVariables->setSelectionMode(QAbstractItemView::SingleSelection);
        listVariables->setRootIsDecorated(false);
        listVariables->setItemsExpandable(false);
        listVariables->setAllColumnsShowFocus(true);

        horizontalLayout->addWidget(listVariables);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        buttonAdd = new QPushButton(groupBox);
        buttonAdd->setObjectName(QString::fromUtf8("buttonAdd"));

        verticalLayout->addWidget(buttonAdd);

        buttonRemove = new QPushButton(groupBox);
        buttonRemove->setObjectName(QString::fromUtf8("buttonRemove"));

        verticalLayout->addWidget(buttonRemove);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout->addLayout(verticalLayout);


        verticalLayout_2->addLayout(horizontalLayout);

        splitter->addWidget(groupBox);
        groupBox_2 = new QGroupBox(splitter);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        verticalLayout_4 = new QVBoxLayout(groupBox_2);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        labelDescDef = new QLabel(groupBox_2);
        labelDescDef->setObjectName(QString::fromUtf8("labelDescDef"));

        verticalLayout_4->addWidget(labelDescDef);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        textCode = new QTextEdit(groupBox_2);
        textCode->setObjectName(QString::fromUtf8("textCode"));
        textCode->setLineWrapMode(QTextEdit::NoWrap);
        textCode->setAcceptRichText(false);

        horizontalLayout_2->addWidget(textCode);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        buttonSave = new QPushButton(groupBox_2);
        buttonSave->setObjectName(QString::fromUtf8("buttonSave"));

        verticalLayout_3->addWidget(buttonSave);

        buttonLoad = new QPushButton(groupBox_2);
        buttonLoad->setObjectName(QString::fromUtf8("buttonLoad"));

        verticalLayout_3->addWidget(buttonLoad);

        buttonInsert = new QPushButton(groupBox_2);
        buttonInsert->setObjectName(QString::fromUtf8("buttonInsert"));
        buttonInsert->setCheckable(false);

        verticalLayout_3->addWidget(buttonInsert);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_2);

        buttonTest = new QPushButton(groupBox_2);
        buttonTest->setObjectName(QString::fromUtf8("buttonTest"));

        verticalLayout_3->addWidget(buttonTest);


        horizontalLayout_2->addLayout(verticalLayout_3);


        verticalLayout_4->addLayout(horizontalLayout_2);

        splitter->addWidget(groupBox_2);

        verticalLayout_5->addWidget(splitter);


        retranslateUi(ScriptPluginWidget);

        QMetaObject::connectSlotsByName(ScriptPluginWidget);
    } // setupUi

    void retranslateUi(QWidget *ScriptPluginWidget)
    {
        groupBox->setTitle(tr2i18n("&Variables", nullptr));
        labelDescVariables->setText(tr2i18n("Declare global variables that can be used from within your functions:", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = listVariables->headerItem();
        ___qtreewidgetitem->setText(0, tr2i18n("1", nullptr));
        buttonAdd->setText(tr2i18n("&Add...", nullptr));
        buttonRemove->setText(tr2i18n("&Delete", nullptr));
        groupBox_2->setTitle(tr2i18n("&Definitions", nullptr));
        labelDescDef->setText(tr2i18n("Define functions that can be used from KRename templates:", nullptr));
        buttonSave->setText(tr2i18n("&Save to File...", nullptr));
        buttonLoad->setText(tr2i18n("&Load from File...", nullptr));
        buttonInsert->setText(tr2i18n("&Insert Variable", nullptr));
        buttonTest->setText(tr2i18n("&Test...", nullptr));
        (void)ScriptPluginWidget;
    } // retranslateUi

};

namespace Ui {
    class ScriptPluginWidget: public Ui_ScriptPluginWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCRIPTPLUGINWIDGET_H

