/****************************************************************************
** Meta object code from reading C++ file 'batchrenamer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../krename-5.0.2/src/batchrenamer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'batchrenamer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BatchRenamer_t {
    QByteArrayData data[20];
    char stringdata0[234];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BatchRenamer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BatchRenamer_t qt_meta_stringdata_BatchRenamer = {
    {
QT_MOC_LITERAL(0, 0, 12), // "BatchRenamer"
QT_MOC_LITERAL(1, 13, 13), // "setRenameMode"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 11), // "ERenameMode"
QT_MOC_LITERAL(4, 40, 4), // "mode"
QT_MOC_LITERAL(5, 45, 19), // "setFilenameTemplate"
QT_MOC_LITERAL(6, 65, 1), // "t"
QT_MOC_LITERAL(7, 67, 20), // "setExtensionTemplate"
QT_MOC_LITERAL(8, 88, 19), // "setNumberStartIndex"
QT_MOC_LITERAL(9, 108, 1), // "i"
QT_MOC_LITERAL(10, 110, 17), // "setNumberStepping"
QT_MOC_LITERAL(11, 128, 1), // "s"
QT_MOC_LITERAL(12, 130, 14), // "setNumberReset"
QT_MOC_LITERAL(13, 145, 1), // "r"
QT_MOC_LITERAL(14, 147, 17), // "setNumberSkipList"
QT_MOC_LITERAL(15, 165, 10), // "QList<int>"
QT_MOC_LITERAL(16, 176, 25), // "setOverwriteExistingFiles"
QT_MOC_LITERAL(17, 202, 9), // "overwrite"
QT_MOC_LITERAL(18, 212, 17), // "setDestinationDir"
QT_MOC_LITERAL(19, 230, 3) // "url"

    },
    "BatchRenamer\0setRenameMode\0\0ERenameMode\0"
    "mode\0setFilenameTemplate\0t\0"
    "setExtensionTemplate\0setNumberStartIndex\0"
    "i\0setNumberStepping\0s\0setNumberReset\0"
    "r\0setNumberSkipList\0QList<int>\0"
    "setOverwriteExistingFiles\0overwrite\0"
    "setDestinationDir\0url"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BatchRenamer[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x0a /* Public */,
       5,    1,   62,    2, 0x0a /* Public */,
       7,    1,   65,    2, 0x0a /* Public */,
       8,    1,   68,    2, 0x0a /* Public */,
      10,    1,   71,    2, 0x0a /* Public */,
      12,    1,   74,    2, 0x0a /* Public */,
      14,    1,   77,    2, 0x0a /* Public */,
      16,    1,   80,    2, 0x0a /* Public */,
      18,    1,   83,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Bool,   13,
    QMetaType::Void, 0x80000000 | 15,   11,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void, QMetaType::QUrl,   19,

       0        // eod
};

void BatchRenamer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BatchRenamer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setRenameMode((*reinterpret_cast< ERenameMode(*)>(_a[1]))); break;
        case 1: _t->setFilenameTemplate((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->setExtensionTemplate((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->setNumberStartIndex((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->setNumberStepping((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->setNumberReset((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->setNumberSkipList((*reinterpret_cast< const QList<int>(*)>(_a[1]))); break;
        case 7: _t->setOverwriteExistingFiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->setDestinationDir((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject BatchRenamer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_BatchRenamer.data,
    qt_meta_data_BatchRenamer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BatchRenamer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BatchRenamer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BatchRenamer.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BatchRenamer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
