#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'startupinfowidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STARTUPINFOWIDGET_H
#define UI_STARTUPINFOWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "kurllabel.h"

QT_BEGIN_NAMESPACE

class Ui_StartUpInfoWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLabel *krenameIcon;
    QGridLayout *gridLayout;
    QLabel *addIcon;
    KUrlLabel *labelAdd;
    QLabel *templateIcon;
    KUrlLabel *labelTemplate;
    QSpacerItem *verticalSpacer;
    QLabel *label_2;

    void setupUi(QFrame *StartUpInfoWidget)
    {
        if (StartUpInfoWidget->objectName().isEmpty())
            StartUpInfoWidget->setObjectName(QString::fromUtf8("StartUpInfoWidget"));
        StartUpInfoWidget->resize(429, 362);
        StartUpInfoWidget->setFrameShape(QFrame::Box);
        StartUpInfoWidget->setFrameShadow(QFrame::Sunken);
        verticalLayout = new QVBoxLayout(StartUpInfoWidget);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label = new QLabel(StartUpInfoWidget);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout->addWidget(label);

        krenameIcon = new QLabel(StartUpInfoWidget);
        krenameIcon->setObjectName(QString::fromUtf8("krenameIcon"));
        krenameIcon->setScaledContents(false);

        horizontalLayout->addWidget(krenameIcon);


        verticalLayout->addLayout(horizontalLayout);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        addIcon = new QLabel(StartUpInfoWidget);
        addIcon->setObjectName(QString::fromUtf8("addIcon"));

        gridLayout->addWidget(addIcon, 0, 0, 1, 1);

        labelAdd = new KUrlLabel(StartUpInfoWidget);
        labelAdd->setObjectName(QString::fromUtf8("labelAdd"));

        gridLayout->addWidget(labelAdd, 0, 1, 1, 1);

        templateIcon = new QLabel(StartUpInfoWidget);
        templateIcon->setObjectName(QString::fromUtf8("templateIcon"));

        gridLayout->addWidget(templateIcon, 1, 0, 1, 1);

        labelTemplate = new KUrlLabel(StartUpInfoWidget);
        labelTemplate->setObjectName(QString::fromUtf8("labelTemplate"));

        gridLayout->addWidget(labelTemplate, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 189, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        label_2 = new QLabel(StartUpInfoWidget);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        verticalLayout->addWidget(label_2);


        retranslateUi(StartUpInfoWidget);

        QMetaObject::connectSlotsByName(StartUpInfoWidget);
    } // setupUi

    void retranslateUi(QFrame *StartUpInfoWidget)
    {
        label->setText(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:large; font-weight:600;\">Welcome to KRename</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">A batch file renamer by KDE.<br />To rename your files, you have to:</p></body></html>", nullptr));
        krenameIcon->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        addIcon->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        labelAdd->setText(tr2i18n("Add some files ...", nullptr));
        templateIcon->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        labelTemplate->setText(tr2i18n("Specify the new filenames by giving a template ...", nullptr));
        label_2->setText(tr2i18n("Hint: Undo is still possible after renaming your files.", nullptr));
        (void)StartUpInfoWidget;
    } // retranslateUi

};

namespace Ui {
    class StartUpInfoWidget: public Ui_StartUpInfoWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STARTUPINFOWIDGET_H

