#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'krenamefiles.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KRENAMEFILES_H
#define UI_KRENAMEFILES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "krenamelistview.h"

QT_BEGIN_NAMESPACE

class Ui_KRenameFiles
{
public:
    QHBoxLayout *horizontalLayout_2;
    KRenameListView *fileList;
    QVBoxLayout *verticalLayout;
    QPushButton *buttonAdd;
    QPushButton *buttonRemove;
    QPushButton *buttonRemoveAll;
    QGridLayout *gridLayout;
    QLabel *label;
    QComboBox *comboSort;
    QLabel *labelCustomSort;
    QCheckBox *checkPreview;
    QCheckBox *checkName;
    QLabel *labelCount;
    QSpacerItem *spacerItem;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout;
    QPushButton *buttonUp;
    QPushButton *buttonDown;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *KRenameFiles)
    {
        if (KRenameFiles->objectName().isEmpty())
            KRenameFiles->setObjectName(QString::fromUtf8("KRenameFiles"));
        KRenameFiles->resize(483, 442);
        horizontalLayout_2 = new QHBoxLayout(KRenameFiles);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        fileList = new KRenameListView(KRenameFiles);
        fileList->setObjectName(QString::fromUtf8("fileList"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(2);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(fileList->sizePolicy().hasHeightForWidth());
        fileList->setSizePolicy(sizePolicy);
        fileList->setSizeIncrement(QSize(0, 0));
        fileList->setAcceptDrops(true);
        fileList->setEditTriggers(QAbstractItemView::NoEditTriggers);
        fileList->setDragDropMode(QAbstractItemView::DragDrop);
        fileList->setAlternatingRowColors(true);
        fileList->setSelectionMode(QAbstractItemView::ExtendedSelection);
        fileList->setUniformItemSizes(true);

        horizontalLayout_2->addWidget(fileList);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        buttonAdd = new QPushButton(KRenameFiles);
        buttonAdd->setObjectName(QString::fromUtf8("buttonAdd"));

        verticalLayout->addWidget(buttonAdd);

        buttonRemove = new QPushButton(KRenameFiles);
        buttonRemove->setObjectName(QString::fromUtf8("buttonRemove"));

        verticalLayout->addWidget(buttonRemove);

        buttonRemoveAll = new QPushButton(KRenameFiles);
        buttonRemoveAll->setObjectName(QString::fromUtf8("buttonRemoveAll"));

        verticalLayout->addWidget(buttonRemoveAll);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label = new QLabel(KRenameFiles);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        comboSort = new QComboBox(KRenameFiles);
        comboSort->addItem(QString());
        comboSort->addItem(QString());
        comboSort->addItem(QString());
        comboSort->addItem(QString());
        comboSort->addItem(QString());
        comboSort->addItem(QString());
        comboSort->addItem(QString());
        comboSort->addItem(QString());
        comboSort->setObjectName(QString::fromUtf8("comboSort"));

        gridLayout->addWidget(comboSort, 0, 1, 1, 1);

        labelCustomSort = new QLabel(KRenameFiles);
        labelCustomSort->setObjectName(QString::fromUtf8("labelCustomSort"));

        gridLayout->addWidget(labelCustomSort, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        checkPreview = new QCheckBox(KRenameFiles);
        checkPreview->setObjectName(QString::fromUtf8("checkPreview"));

        verticalLayout->addWidget(checkPreview);

        checkName = new QCheckBox(KRenameFiles);
        checkName->setObjectName(QString::fromUtf8("checkName"));
        checkName->setChecked(true);

        verticalLayout->addWidget(checkName);

        labelCount = new QLabel(KRenameFiles);
        labelCount->setObjectName(QString::fromUtf8("labelCount"));

        verticalLayout->addWidget(labelCount);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(spacerItem);

        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        vboxLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        buttonUp = new QPushButton(KRenameFiles);
        buttonUp->setObjectName(QString::fromUtf8("buttonUp"));

        vboxLayout->addWidget(buttonUp);

        buttonDown = new QPushButton(KRenameFiles);
        buttonDown->setObjectName(QString::fromUtf8("buttonDown"));

        vboxLayout->addWidget(buttonDown);


        hboxLayout->addLayout(vboxLayout);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem1);


        verticalLayout->addLayout(hboxLayout);

        spacerItem2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(spacerItem2);


        horizontalLayout_2->addLayout(verticalLayout);

#if QT_CONFIG(shortcut)
        label->setBuddy(comboSort);
#endif // QT_CONFIG(shortcut)

        retranslateUi(KRenameFiles);

        buttonAdd->setDefault(true);


        QMetaObject::connectSlotsByName(KRenameFiles);
    } // setupUi

    void retranslateUi(QWidget *KRenameFiles)
    {
#if QT_CONFIG(tooltip)
        buttonAdd->setToolTip(tr2i18n("Add files for renaming.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonAdd->setText(tr2i18n("&Add...", nullptr));
#if QT_CONFIG(tooltip)
        buttonRemove->setToolTip(tr2i18n("Remove selected files.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonRemove->setText(tr2i18n("Re&move", nullptr));
#if QT_CONFIG(tooltip)
        buttonRemoveAll->setToolTip(tr2i18n("Remove all files.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonRemoveAll->setText(tr2i18n("Re&move All", nullptr));
        label->setText(tr2i18n("Sort:", nullptr));
        comboSort->setItemText(0, tr2i18n("Unsorted", nullptr));
        comboSort->setItemText(1, tr2i18n("Ascending", nullptr));
        comboSort->setItemText(2, tr2i18n("Descending", nullptr));
        comboSort->setItemText(3, tr2i18n("Numeric", nullptr));
        comboSort->setItemText(4, tr2i18n("Random", nullptr));
        comboSort->setItemText(5, tr2i18n("Date (Asc.)", nullptr));
        comboSort->setItemText(6, tr2i18n("Date (Desc.)", nullptr));
        comboSort->setItemText(7, tr2i18n("Custom ...", nullptr));

        labelCustomSort->setText(QString());
#if QT_CONFIG(tooltip)
        checkPreview->setToolTip(tr2i18n("Display a preview image for each file.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkPreview->setText(tr2i18n("&Preview", nullptr));
#if QT_CONFIG(tooltip)
        checkName->setToolTip(tr2i18n("Display the filename together with the preview.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkName->setText(tr2i18n("&Display name", nullptr));
        labelCount->setText(tr2i18n("Files: <b>0</b>", nullptr));
#if QT_CONFIG(tooltip)
        buttonUp->setToolTip(tr2i18n("Move selected files upwards.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonUp->setText(tr2i18n("Up", nullptr));
#if QT_CONFIG(tooltip)
        buttonDown->setToolTip(tr2i18n("Move selected files downwards.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonDown->setText(tr2i18n("Down", nullptr));
        (void)KRenameFiles;
    } // retranslateUi

};

namespace Ui {
    class KRenameFiles: public Ui_KRenameFiles {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KRENAMEFILES_H

