#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'partfilenamewidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PARTFILENAMEWIDGET_H
#define UI_PARTFILENAMEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "selectionsafelineedit.h"

QT_BEGIN_NAMESPACE

class Ui_PartFilenameWidget
{
public:
    QVBoxLayout *vboxLayout;
    QFrame *frame;
    QVBoxLayout *vboxLayout1;
    QLabel *label;
    SelectionSafeLineEdit *textFilename;
    QCheckBox *checkInvert;
    QHBoxLayout *hboxLayout;
    QLabel *label_2;
    QComboBox *comboConvert;
    QLabel *labelPreviewDesc;
    QLabel *labelPreview;

    void setupUi(QWidget *PartFilenameWidget)
    {
        if (PartFilenameWidget->objectName().isEmpty())
            PartFilenameWidget->setObjectName(QString::fromUtf8("PartFilenameWidget"));
        PartFilenameWidget->resize(412, 275);
        vboxLayout = new QVBoxLayout(PartFilenameWidget);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        frame = new QFrame(PartFilenameWidget);
        frame->setObjectName(QString::fromUtf8("frame"));
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        vboxLayout1 = new QVBoxLayout(frame);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        label = new QLabel(frame);
        label->setObjectName(QString::fromUtf8("label"));
        label->setWordWrap(true);

        vboxLayout1->addWidget(label);

        textFilename = new SelectionSafeLineEdit(frame);
        textFilename->setObjectName(QString::fromUtf8("textFilename"));
        textFilename->setReadOnly(true);

        vboxLayout1->addWidget(textFilename);

        checkInvert = new QCheckBox(frame);
        checkInvert->setObjectName(QString::fromUtf8("checkInvert"));

        vboxLayout1->addWidget(checkInvert);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        label_2 = new QLabel(frame);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        hboxLayout->addWidget(label_2);

        comboConvert = new QComboBox(frame);
        comboConvert->addItem(QString());
        comboConvert->addItem(QString());
        comboConvert->addItem(QString());
        comboConvert->addItem(QString());
        comboConvert->setObjectName(QString::fromUtf8("comboConvert"));

        hboxLayout->addWidget(comboConvert);


        vboxLayout1->addLayout(hboxLayout);

        labelPreviewDesc = new QLabel(frame);
        labelPreviewDesc->setObjectName(QString::fromUtf8("labelPreviewDesc"));

        vboxLayout1->addWidget(labelPreviewDesc);

        labelPreview = new QLabel(frame);
        labelPreview->setObjectName(QString::fromUtf8("labelPreview"));

        vboxLayout1->addWidget(labelPreview);


        vboxLayout->addWidget(frame);

#if QT_CONFIG(shortcut)
        label->setBuddy(textFilename);
        label_2->setBuddy(comboConvert);
#endif // QT_CONFIG(shortcut)

        retranslateUi(PartFilenameWidget);

        QMetaObject::connectSlotsByName(PartFilenameWidget);
    } // setupUi

    void retranslateUi(QWidget *PartFilenameWidget)
    {
        label->setText(tr2i18n("<qt>Please select the part of the old filename  which should be inserted into the new filename in the textbox below:</qt>", nullptr));
        checkInvert->setText(tr2i18n("&Invert selection", nullptr));
        label_2->setText(tr2i18n("&Convert selection:", nullptr));
        comboConvert->setItemText(0, tr2i18n("No Conversion", nullptr));
        comboConvert->setItemText(1, tr2i18n("Convert to lower case", nullptr));
        comboConvert->setItemText(2, tr2i18n("Convert to upper case", nullptr));
        comboConvert->setItemText(3, tr2i18n("Capitalize", nullptr));

        labelPreviewDesc->setText(tr2i18n("Preview of the generated KRename command:", nullptr));
        labelPreview->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        (void)PartFilenameWidget;
    } // retranslateUi

};

namespace Ui {
    class PartFilenameWidget: public Ui_PartFilenameWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PARTFILENAMEWIDGET_H

