#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'permissionspluginwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PERMISSIONSPLUGINWIDGET_H
#define UI_PERMISSIONSPLUGINWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_PermissionsPluginWidget
{
public:
    QVBoxLayout *vboxLayout;
    QCheckBox *checkPermissions;
    QGroupBox *groupPermissions;
    QVBoxLayout *vboxLayout1;
    QGridLayout *gridLayout;
    QLabel *label_3;
    QComboBox *comboPermOwner;
    QLabel *label_4;
    QComboBox *comboPermGroup;
    QLabel *label_5;
    QComboBox *comboPermOthers;
    QLabel *labelAdvanced;
    QCheckBox *checkFolder;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacerItem;
    QPushButton *pushButton;
    QCheckBox *checkOwner;
    QGroupBox *groupOwner;
    QGridLayout *gridLayout1;
    QLabel *label;
    QComboBox *comboUser;
    QSpacerItem *spacerItem1;
    QLabel *label_2;
    QComboBox *comboGroup;
    QSpacerItem *spacerItem2;
    QSpacerItem *spacerItem3;

    void setupUi(QWidget *PermissionsPluginWidget)
    {
        if (PermissionsPluginWidget->objectName().isEmpty())
            PermissionsPluginWidget->setObjectName(QString::fromUtf8("PermissionsPluginWidget"));
        PermissionsPluginWidget->resize(596, 539);
        vboxLayout = new QVBoxLayout(PermissionsPluginWidget);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        checkPermissions = new QCheckBox(PermissionsPluginWidget);
        checkPermissions->setObjectName(QString::fromUtf8("checkPermissions"));

        vboxLayout->addWidget(checkPermissions);

        groupPermissions = new QGroupBox(PermissionsPluginWidget);
        groupPermissions->setObjectName(QString::fromUtf8("groupPermissions"));
        groupPermissions->setEnabled(false);
        vboxLayout1 = new QVBoxLayout(groupPermissions);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label_3 = new QLabel(groupPermissions);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        comboPermOwner = new QComboBox(groupPermissions);
        comboPermOwner->addItem(QString());
        comboPermOwner->addItem(QString());
        comboPermOwner->addItem(QString());
        comboPermOwner->setObjectName(QString::fromUtf8("comboPermOwner"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(2);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(comboPermOwner->sizePolicy().hasHeightForWidth());
        comboPermOwner->setSizePolicy(sizePolicy);

        gridLayout->addWidget(comboPermOwner, 1, 1, 1, 1);

        label_4 = new QLabel(groupPermissions);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout->addWidget(label_4, 2, 0, 1, 1);

        comboPermGroup = new QComboBox(groupPermissions);
        comboPermGroup->addItem(QString());
        comboPermGroup->addItem(QString());
        comboPermGroup->addItem(QString());
        comboPermGroup->setObjectName(QString::fromUtf8("comboPermGroup"));
        sizePolicy.setHeightForWidth(comboPermGroup->sizePolicy().hasHeightForWidth());
        comboPermGroup->setSizePolicy(sizePolicy);

        gridLayout->addWidget(comboPermGroup, 2, 1, 1, 1);

        label_5 = new QLabel(groupPermissions);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        gridLayout->addWidget(label_5, 3, 0, 1, 1);

        comboPermOthers = new QComboBox(groupPermissions);
        comboPermOthers->addItem(QString());
        comboPermOthers->addItem(QString());
        comboPermOthers->addItem(QString());
        comboPermOthers->setObjectName(QString::fromUtf8("comboPermOthers"));
        sizePolicy.setHeightForWidth(comboPermOthers->sizePolicy().hasHeightForWidth());
        comboPermOthers->setSizePolicy(sizePolicy);

        gridLayout->addWidget(comboPermOthers, 3, 1, 1, 1);

        labelAdvanced = new QLabel(groupPermissions);
        labelAdvanced->setObjectName(QString::fromUtf8("labelAdvanced"));

        gridLayout->addWidget(labelAdvanced, 0, 0, 1, 2);


        vboxLayout1->addLayout(gridLayout);

        checkFolder = new QCheckBox(groupPermissions);
        checkFolder->setObjectName(QString::fromUtf8("checkFolder"));

        vboxLayout1->addWidget(checkFolder);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);

        pushButton = new QPushButton(groupPermissions);
        pushButton->setObjectName(QString::fromUtf8("pushButton"));

        hboxLayout->addWidget(pushButton);


        vboxLayout1->addLayout(hboxLayout);


        vboxLayout->addWidget(groupPermissions);

        checkOwner = new QCheckBox(PermissionsPluginWidget);
        checkOwner->setObjectName(QString::fromUtf8("checkOwner"));

        vboxLayout->addWidget(checkOwner);

        groupOwner = new QGroupBox(PermissionsPluginWidget);
        groupOwner->setObjectName(QString::fromUtf8("groupOwner"));
        groupOwner->setEnabled(false);
        gridLayout1 = new QGridLayout(groupOwner);
        gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
        label = new QLabel(groupOwner);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout1->addWidget(label, 0, 0, 1, 1);

        comboUser = new QComboBox(groupOwner);
        comboUser->setObjectName(QString::fromUtf8("comboUser"));

        gridLayout1->addWidget(comboUser, 0, 1, 1, 1);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout1->addItem(spacerItem1, 0, 2, 1, 1);

        label_2 = new QLabel(groupOwner);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout1->addWidget(label_2, 1, 0, 1, 1);

        comboGroup = new QComboBox(groupOwner);
        comboGroup->setObjectName(QString::fromUtf8("comboGroup"));

        gridLayout1->addWidget(comboGroup, 1, 1, 1, 1);

        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout1->addItem(spacerItem2, 1, 2, 1, 1);


        vboxLayout->addWidget(groupOwner);

        spacerItem3 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem3);

#if QT_CONFIG(shortcut)
        label_3->setBuddy(comboPermOwner);
        label_4->setBuddy(comboPermGroup);
        label_5->setBuddy(comboPermOthers);
        label->setBuddy(comboUser);
        label_2->setBuddy(comboGroup);
#endif // QT_CONFIG(shortcut)

        retranslateUi(PermissionsPluginWidget);

        QMetaObject::connectSlotsByName(PermissionsPluginWidget);
    } // setupUi

    void retranslateUi(QWidget *PermissionsPluginWidget)
    {
        checkPermissions->setText(tr2i18n("Change &Permissions", nullptr));
        groupPermissions->setTitle(tr2i18n("Access Permissions", nullptr));
        label_3->setText(tr2i18n("O&wner:", nullptr));
        comboPermOwner->setItemText(0, tr2i18n("Forbidden", nullptr));
        comboPermOwner->setItemText(1, tr2i18n("Can Read", nullptr));
        comboPermOwner->setItemText(2, tr2i18n("Can Read & Write", nullptr));

        label_4->setText(tr2i18n("Gro&up:", nullptr));
        comboPermGroup->setItemText(0, tr2i18n("Forbidden", nullptr));
        comboPermGroup->setItemText(1, tr2i18n("Can Read", nullptr));
        comboPermGroup->setItemText(2, tr2i18n("Can Read & Write", nullptr));

        label_5->setText(tr2i18n("Ot&hers:", nullptr));
        comboPermOthers->setItemText(0, tr2i18n("Forbidden", nullptr));
        comboPermOthers->setItemText(1, tr2i18n("Can Read", nullptr));
        comboPermOthers->setItemText(2, tr2i18n("Can Read & Write", nullptr));

        labelAdvanced->setText(tr2i18n("This file uses advanced permissions", nullptr));
        checkFolder->setText(tr2i18n("Is Executable/Only owner &can rename and delete folder content", nullptr));
        pushButton->setText(tr2i18n("A&dvanced Permissions", nullptr));
        checkOwner->setText(tr2i18n("&Change Owner", nullptr));
        groupOwner->setTitle(tr2i18n("Ownership", nullptr));
        label->setText(tr2i18n("&User:", nullptr));
        label_2->setText(tr2i18n("&Group:", nullptr));
        (void)PermissionsPluginWidget;
    } // retranslateUi

};

namespace Ui {
    class PermissionsPluginWidget: public Ui_PermissionsPluginWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PERMISSIONSPLUGINWIDGET_H

