#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'customfilenamedlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUSTOMFILENAMEDLG_H
#define UI_CUSTOMFILENAMEDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CustomFilenameDlg
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer_2;
    QLabel *labelPreview;
    QSpacerItem *verticalSpacer;
    QLabel *label;
    QSpacerItem *horizontalSpacer;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_3;
    QRadioButton *radioKRename;
    QGridLayout *gridLayout;
    QRadioButton *radioInput;
    QRadioButton *radioCustom;
    QLineEdit *lineEditCustom;
    QLineEdit *lineEditInput;
    QSpacerItem *spacer;

    void setupUi(QWidget *CustomFilenameDlg)
    {
        if (CustomFilenameDlg->objectName().isEmpty())
            CustomFilenameDlg->setObjectName(QString::fromUtf8("CustomFilenameDlg"));
        CustomFilenameDlg->resize(523, 298);
        verticalLayout_2 = new QVBoxLayout(CustomFilenameDlg);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        labelPreview = new QLabel(CustomFilenameDlg);
        labelPreview->setObjectName(QString::fromUtf8("labelPreview"));
        labelPreview->setFrameShape(QFrame::NoFrame);
        labelPreview->setScaledContents(true);
        labelPreview->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(labelPreview);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        label = new QLabel(CustomFilenameDlg);
        label->setObjectName(QString::fromUtf8("label"));
        label->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(label);


        horizontalLayout->addLayout(verticalLayout);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        groupBox = new QGroupBox(CustomFilenameDlg);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        verticalLayout_3 = new QVBoxLayout(groupBox);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        radioKRename = new QRadioButton(groupBox);
        radioKRename->setObjectName(QString::fromUtf8("radioKRename"));
        radioKRename->setChecked(true);

        verticalLayout_3->addWidget(radioKRename);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        radioInput = new QRadioButton(groupBox);
        radioInput->setObjectName(QString::fromUtf8("radioInput"));

        gridLayout->addWidget(radioInput, 0, 0, 1, 1);

        radioCustom = new QRadioButton(groupBox);
        radioCustom->setObjectName(QString::fromUtf8("radioCustom"));

        gridLayout->addWidget(radioCustom, 1, 0, 1, 1);

        lineEditCustom = new QLineEdit(groupBox);
        lineEditCustom->setObjectName(QString::fromUtf8("lineEditCustom"));

        gridLayout->addWidget(lineEditCustom, 1, 1, 1, 1);

        lineEditInput = new QLineEdit(groupBox);
        lineEditInput->setObjectName(QString::fromUtf8("lineEditInput"));

        gridLayout->addWidget(lineEditInput, 0, 1, 1, 1);


        verticalLayout_3->addLayout(gridLayout);


        horizontalLayout->addWidget(groupBox);


        verticalLayout_2->addLayout(horizontalLayout);

        spacer = new QSpacerItem(20, 141, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(spacer);


        retranslateUi(CustomFilenameDlg);

        QMetaObject::connectSlotsByName(CustomFilenameDlg);
    } // setupUi

    void retranslateUi(QWidget *CustomFilenameDlg)
    {
        labelPreview->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        label->setText(tr2i18n("File preview", nullptr));
        groupBox->setTitle(tr2i18n("Please input a new filename", nullptr));
#if QT_CONFIG(tooltip)
        radioKRename->setToolTip(tr2i18n("Rename the file using the filename created by KRename.", nullptr));
#endif // QT_CONFIG(tooltip)
        radioKRename->setText(tr2i18n("Use filename created by &KRename", nullptr));
#if QT_CONFIG(tooltip)
        radioInput->setToolTip(tr2i18n("Use the input filename when renaming this file. You may also change the input filename and use this for renaming.", nullptr));
#endif // QT_CONFIG(tooltip)
        radioInput->setText(tr2i18n("Use &input filename", nullptr));
#if QT_CONFIG(tooltip)
        radioCustom->setToolTip(tr2i18n("Use a custom filename, based on the filename currently created by KRename.", nullptr));
#endif // QT_CONFIG(tooltip)
        radioCustom->setText(tr2i18n("Use &custom filename", nullptr));
        (void)CustomFilenameDlg;
    } // retranslateUi

};

namespace Ui {
    class CustomFilenameDlg: public Ui_CustomFilenameDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CUSTOMFILENAMEDLG_H

