/****************************************************************************
** Meta object code from reading C++ file 'scriptplugin.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../krename-5.0.2/src/scriptplugin.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scriptplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ScriptPlugin_t {
    QByteArrayData data[13];
    char stringdata0[168];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ScriptPlugin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ScriptPlugin_t qt_meta_stringdata_ScriptPlugin = {
    {
QT_MOC_LITERAL(0, 0, 12), // "ScriptPlugin"
QT_MOC_LITERAL(1, 13, 18), // "slotEnableControls"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 7), // "slotAdd"
QT_MOC_LITERAL(4, 41, 10), // "slotRemove"
QT_MOC_LITERAL(5, 52, 8), // "slotSave"
QT_MOC_LITERAL(6, 61, 8), // "slotLoad"
QT_MOC_LITERAL(7, 70, 8), // "slotTest"
QT_MOC_LITERAL(8, 79, 15), // "slotInsertIndex"
QT_MOC_LITERAL(9, 95, 13), // "slotInsertUrl"
QT_MOC_LITERAL(10, 109, 18), // "slotInsertFilename"
QT_MOC_LITERAL(11, 128, 19), // "slotInsertExtension"
QT_MOC_LITERAL(12, 148, 19) // "slotInsertDirectory"

    },
    "ScriptPlugin\0slotEnableControls\0\0"
    "slotAdd\0slotRemove\0slotSave\0slotLoad\0"
    "slotTest\0slotInsertIndex\0slotInsertUrl\0"
    "slotInsertFilename\0slotInsertExtension\0"
    "slotInsertDirectory"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ScriptPlugin[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x08 /* Private */,
       3,    0,   70,    2, 0x08 /* Private */,
       4,    0,   71,    2, 0x08 /* Private */,
       5,    0,   72,    2, 0x08 /* Private */,
       6,    0,   73,    2, 0x08 /* Private */,
       7,    0,   74,    2, 0x08 /* Private */,
       8,    0,   75,    2, 0x08 /* Private */,
       9,    0,   76,    2, 0x08 /* Private */,
      10,    0,   77,    2, 0x08 /* Private */,
      11,    0,   78,    2, 0x08 /* Private */,
      12,    0,   79,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ScriptPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ScriptPlugin *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slotEnableControls(); break;
        case 1: _t->slotAdd(); break;
        case 2: _t->slotRemove(); break;
        case 3: _t->slotSave(); break;
        case 4: _t->slotLoad(); break;
        case 5: _t->slotTest(); break;
        case 6: _t->slotInsertIndex(); break;
        case 7: _t->slotInsertUrl(); break;
        case 8: _t->slotInsertFilename(); break;
        case 9: _t->slotInsertExtension(); break;
        case 10: _t->slotInsertDirectory(); break;
        default: ;
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ScriptPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_ScriptPlugin.data,
    qt_meta_data_ScriptPlugin,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ScriptPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScriptPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ScriptPlugin.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Plugin"))
        return static_cast< Plugin*>(this);
    return QObject::qt_metacast(_clname);
}

int ScriptPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
