#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'replacewidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_REPLACEWIDGET_H
#define UI_REPLACEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ReplaceWidget
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QTableWidget *list;
    QVBoxLayout *vboxLayout1;
    QSpacerItem *spacerItem;
    QPushButton *buttonSaveList;
    QPushButton *buttonLoadList;
    QSpacerItem *verticalSpacer;
    QPushButton *buttonAdd;
    QPushButton *buttonEdit;
    QPushButton *buttonRemove;
    QSpacerItem *spacerItem1;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *ReplaceWidget)
    {
        if (ReplaceWidget->objectName().isEmpty())
            ReplaceWidget->setObjectName(QString::fromUtf8("ReplaceWidget"));
        ReplaceWidget->resize(453, 305);
        vboxLayout = new QVBoxLayout(ReplaceWidget);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        list = new QTableWidget(ReplaceWidget);
        if (list->columnCount() < 4)
            list->setColumnCount(4);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        list->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        list->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        list->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        list->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        list->setObjectName(QString::fromUtf8("list"));
        list->setAlternatingRowColors(true);
        list->setSelectionMode(QAbstractItemView::SingleSelection);
        list->setSelectionBehavior(QAbstractItemView::SelectRows);

        hboxLayout->addWidget(list);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout1->addItem(spacerItem);

        buttonSaveList = new QPushButton(ReplaceWidget);
        buttonSaveList->setObjectName(QString::fromUtf8("buttonSaveList"));

        vboxLayout1->addWidget(buttonSaveList);

        buttonLoadList = new QPushButton(ReplaceWidget);
        buttonLoadList->setObjectName(QString::fromUtf8("buttonLoadList"));

        vboxLayout1->addWidget(buttonLoadList);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout1->addItem(verticalSpacer);

        buttonAdd = new QPushButton(ReplaceWidget);
        buttonAdd->setObjectName(QString::fromUtf8("buttonAdd"));

        vboxLayout1->addWidget(buttonAdd);

        buttonEdit = new QPushButton(ReplaceWidget);
        buttonEdit->setObjectName(QString::fromUtf8("buttonEdit"));

        vboxLayout1->addWidget(buttonEdit);

        buttonRemove = new QPushButton(ReplaceWidget);
        buttonRemove->setObjectName(QString::fromUtf8("buttonRemove"));

        vboxLayout1->addWidget(buttonRemove);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout1->addItem(spacerItem1);


        hboxLayout->addLayout(vboxLayout1);


        vboxLayout->addLayout(hboxLayout);

        buttonBox = new QDialogButtonBox(ReplaceWidget);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        vboxLayout->addWidget(buttonBox);


        retranslateUi(ReplaceWidget);

        QMetaObject::connectSlotsByName(ReplaceWidget);
    } // setupUi

    void retranslateUi(QWidget *ReplaceWidget)
    {
        ReplaceWidget->setWindowTitle(tr2i18n("Find and Replace", nullptr));
        QTableWidgetItem *___qtablewidgetitem = list->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Reg. Expression", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = list->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Find", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = list->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Replace With", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = list->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(tr2i18n("Process Tokens", nullptr));
        buttonSaveList->setText(tr2i18n("&Save Settings...", nullptr));
        buttonLoadList->setText(tr2i18n("&Load Settings...", nullptr));
        buttonAdd->setText(tr2i18n("&Add...", nullptr));
        buttonEdit->setText(tr2i18n("&Edit...", nullptr));
        buttonRemove->setText(tr2i18n("&Remove", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ReplaceWidget: public Ui_ReplaceWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // REPLACEWIDGET_H

