#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'tokenhelpwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TOKENHELPWIDGET_H
#define UI_TOKENHELPWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "KItemViews/ktreewidgetsearchlinewidget.h"

QT_BEGIN_NAMESPACE

class Ui_TokenHelpWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QSplitter *splitter;
    QWidget *leftLayoutWidget;
    QVBoxLayout *vboxLayout;
    KTreeWidgetSearchLineWidget *searchCategory;
    QTreeWidget *listCategories;
    QWidget *rightLayoutWidget;
    QVBoxLayout *vboxLayout1;
    KTreeWidgetSearchLineWidget *searchToken;
    QTreeWidget *listTokens;
    QHBoxLayout *horizontalLayout;
    QCheckBox *checkPreview;
    QSpacerItem *horizontalSpacer;
    QLabel *labelPreview;
    QComboBox *comboPreview;

    void setupUi(QWidget *TokenHelpWidget)
    {
        if (TokenHelpWidget->objectName().isEmpty())
            TokenHelpWidget->setObjectName(QString::fromUtf8("TokenHelpWidget"));
        TokenHelpWidget->resize(494, 379);
        verticalLayout = new QVBoxLayout(TokenHelpWidget);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        label = new QLabel(TokenHelpWidget);
        label->setObjectName(QString::fromUtf8("label"));
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        splitter = new QSplitter(TokenHelpWidget);
        splitter->setObjectName(QString::fromUtf8("splitter"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(splitter->sizePolicy().hasHeightForWidth());
        splitter->setSizePolicy(sizePolicy);
        splitter->setOrientation(Qt::Horizontal);
        leftLayoutWidget = new QWidget(splitter);
        leftLayoutWidget->setObjectName(QString::fromUtf8("leftLayoutWidget"));
        vboxLayout = new QVBoxLayout(leftLayoutWidget);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        searchCategory = new KTreeWidgetSearchLineWidget(leftLayoutWidget);
        searchCategory->setObjectName(QString::fromUtf8("searchCategory"));

        vboxLayout->addWidget(searchCategory);

        listCategories = new QTreeWidget(leftLayoutWidget);
        listCategories->setObjectName(QString::fromUtf8("listCategories"));
        listCategories->setAlternatingRowColors(true);
        listCategories->setRootIsDecorated(false);
        listCategories->setItemsExpandable(false);
        listCategories->setSortingEnabled(true);
        listCategories->setAllColumnsShowFocus(true);

        vboxLayout->addWidget(listCategories);

        splitter->addWidget(leftLayoutWidget);
        rightLayoutWidget = new QWidget(splitter);
        rightLayoutWidget->setObjectName(QString::fromUtf8("rightLayoutWidget"));
        vboxLayout1 = new QVBoxLayout(rightLayoutWidget);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        searchToken = new KTreeWidgetSearchLineWidget(rightLayoutWidget);
        searchToken->setObjectName(QString::fromUtf8("searchToken"));

        vboxLayout1->addWidget(searchToken);

        listTokens = new QTreeWidget(rightLayoutWidget);
        listTokens->setObjectName(QString::fromUtf8("listTokens"));
        listTokens->setAlternatingRowColors(true);
        listTokens->setRootIsDecorated(false);
        listTokens->setItemsExpandable(false);
        listTokens->setSortingEnabled(true);
        listTokens->setAllColumnsShowFocus(true);
        listTokens->setHeaderHidden(false);

        vboxLayout1->addWidget(listTokens);

        splitter->addWidget(rightLayoutWidget);

        verticalLayout->addWidget(splitter);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        checkPreview = new QCheckBox(TokenHelpWidget);
        checkPreview->setObjectName(QString::fromUtf8("checkPreview"));

        horizontalLayout->addWidget(checkPreview);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Minimum, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        labelPreview = new QLabel(TokenHelpWidget);
        labelPreview->setObjectName(QString::fromUtf8("labelPreview"));

        horizontalLayout->addWidget(labelPreview);

        comboPreview = new QComboBox(TokenHelpWidget);
        comboPreview->setObjectName(QString::fromUtf8("comboPreview"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(comboPreview->sizePolicy().hasHeightForWidth());
        comboPreview->setSizePolicy(sizePolicy1);
        comboPreview->setSizeIncrement(QSize(0, 0));
        comboPreview->setEditable(false);

        horizontalLayout->addWidget(comboPreview);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(TokenHelpWidget);

        QMetaObject::connectSlotsByName(TokenHelpWidget);
    } // setupUi

    void retranslateUi(QWidget *TokenHelpWidget)
    {
        TokenHelpWidget->setWindowTitle(tr2i18n("KRename Help", nullptr));
        label->setText(tr2i18n("All supported tokens (commands) are listed in this dialog. You can search for tokens and insert a found token into the pattern for the filename.", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = listCategories->headerItem();
        ___qtreewidgetitem->setText(0, tr2i18n("Category", nullptr));
        QTreeWidgetItem *___qtreewidgetitem1 = listTokens->headerItem();
        ___qtreewidgetitem1->setText(2, tr2i18n("Preview", nullptr));
        ___qtreewidgetitem1->setText(1, tr2i18n("Description", nullptr));
        ___qtreewidgetitem1->setText(0, tr2i18n("Token", nullptr));
        checkPreview->setText(tr2i18n("Token &Preview", nullptr));
        labelPreview->setText(tr2i18n("Preview File:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TokenHelpWidget: public Ui_TokenHelpWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TOKENHELPWIDGET_H

