#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'krenamefilename.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KRENAMEFILENAME_H
#define UI_KRENAMEFILENAME_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "exthistorycombo.h"
#include "previewlist.h"

QT_BEGIN_NAMESPACE

class Ui_KRenameFilename
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *tabWidget;
    QWidget *tabAdvanced;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QLabel *lblTemplate;
    ExtHistoryCombo *filenameTemplate;
    QLabel *lblDot;
    ExtHistoryCombo *extensionTemplate;
    QPushButton *buttonFunctions;
    QHBoxLayout *hboxLayout1;
    QCheckBox *checkExtension;
    QSpacerItem *spacerItem;
    QLabel *lblExtension;
    QComboBox *comboExtension;
    QHBoxLayout *hboxLayout2;
    QPushButton *buttonFind;
    QPushButton *buttonNumbering;
    QPushButton *buttonInsert;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;
    QWidget *tabSimple;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout3;
    QGroupBox *groupFilename;
    QGridLayout *gridLayout;
    QLabel *lblSuffix;
    QPushButton *buttonHelp4;
    QPushButton *buttonHelp3;
    ExtHistoryCombo *comboFilenameCustom;
    QComboBox *comboFilenameSimple;
    QLabel *lblFilename;
    QPushButton *buttonHelp2;
    ExtHistoryCombo *comboSuffixCustom;
    QComboBox *comboSuffix;
    QPushButton *buttonHelp1;
    QLabel *lblPrefix;
    QLabel *lblExtension_2;
    QComboBox *comboPrefix;
    QComboBox *comboExtensionSimple;
    ExtHistoryCombo *comboPrefixCustom;
    ExtHistoryCombo *comboExtensionCustom;
    QVBoxLayout *vboxLayout3;
    QGroupBox *groupNumber;
    QGridLayout *gridLayout1;
    QSpinBox *spinDigits;
    QSpinBox *spinIndex;
    QLabel *lblDigits;
    QLabel *lblIndex;
    QSpacerItem *spacerItem3;
    QPushButton *buttonFindSimple;
    QHBoxLayout *hboxLayout4;
    PreviewList *listPreview;
    QVBoxLayout *vboxLayout4;
    QSpacerItem *spacerItem4;
    QPushButton *buttonUp;
    QPushButton *buttonDown;
    QSpacerItem *spacerItem5;

    void setupUi(QWidget *KRenameFilename)
    {
        if (KRenameFilename->objectName().isEmpty())
            KRenameFilename->setObjectName(QString::fromUtf8("KRenameFilename"));
        KRenameFilename->resize(699, 528);
        vboxLayout = new QVBoxLayout(KRenameFilename);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        tabWidget = new QTabWidget(KRenameFilename);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy);
        tabAdvanced = new QWidget();
        tabAdvanced->setObjectName(QString::fromUtf8("tabAdvanced"));
        vboxLayout1 = new QVBoxLayout(tabAdvanced);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        lblTemplate = new QLabel(tabAdvanced);
        lblTemplate->setObjectName(QString::fromUtf8("lblTemplate"));

        hboxLayout->addWidget(lblTemplate);

        filenameTemplate = new ExtHistoryCombo(tabAdvanced);
        filenameTemplate->addItem(QString());
        filenameTemplate->setObjectName(QString::fromUtf8("filenameTemplate"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(6);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(filenameTemplate->sizePolicy().hasHeightForWidth());
        filenameTemplate->setSizePolicy(sizePolicy1);
        filenameTemplate->setEditable(true);

        hboxLayout->addWidget(filenameTemplate);

        lblDot = new QLabel(tabAdvanced);
        lblDot->setObjectName(QString::fromUtf8("lblDot"));

        hboxLayout->addWidget(lblDot);

        extensionTemplate = new ExtHistoryCombo(tabAdvanced);
        extensionTemplate->addItem(QString());
        extensionTemplate->setObjectName(QString::fromUtf8("extensionTemplate"));
        extensionTemplate->setEnabled(false);
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(2);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(extensionTemplate->sizePolicy().hasHeightForWidth());
        extensionTemplate->setSizePolicy(sizePolicy2);
        extensionTemplate->setEditable(true);

        hboxLayout->addWidget(extensionTemplate);

        buttonFunctions = new QPushButton(tabAdvanced);
        buttonFunctions->setObjectName(QString::fromUtf8("buttonFunctions"));

        hboxLayout->addWidget(buttonFunctions);


        vboxLayout1->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        checkExtension = new QCheckBox(tabAdvanced);
        checkExtension->setObjectName(QString::fromUtf8("checkExtension"));
        checkExtension->setChecked(true);

        hboxLayout1->addWidget(checkExtension);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem);

        lblExtension = new QLabel(tabAdvanced);
        lblExtension->setObjectName(QString::fromUtf8("lblExtension"));

        hboxLayout1->addWidget(lblExtension);

        comboExtension = new QComboBox(tabAdvanced);
        comboExtension->addItem(QString());
        comboExtension->addItem(QString());
        comboExtension->addItem(QString());
        comboExtension->setObjectName(QString::fromUtf8("comboExtension"));

        hboxLayout1->addWidget(comboExtension);


        vboxLayout1->addLayout(hboxLayout1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(6);
        hboxLayout2->setObjectName(QString::fromUtf8("hboxLayout2"));
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        buttonFind = new QPushButton(tabAdvanced);
        buttonFind->setObjectName(QString::fromUtf8("buttonFind"));
        buttonFind->setEnabled(false);

        hboxLayout2->addWidget(buttonFind);

        buttonNumbering = new QPushButton(tabAdvanced);
        buttonNumbering->setObjectName(QString::fromUtf8("buttonNumbering"));
        buttonNumbering->setEnabled(false);

        hboxLayout2->addWidget(buttonNumbering);

        buttonInsert = new QPushButton(tabAdvanced);
        buttonInsert->setObjectName(QString::fromUtf8("buttonInsert"));
        buttonInsert->setEnabled(false);

        hboxLayout2->addWidget(buttonInsert);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout2->addItem(spacerItem1);


        vboxLayout1->addLayout(hboxLayout2);

        spacerItem2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Minimum);

        vboxLayout1->addItem(spacerItem2);

        tabWidget->addTab(tabAdvanced, QString());
        tabSimple = new QWidget();
        tabSimple->setObjectName(QString::fromUtf8("tabSimple"));
        vboxLayout2 = new QVBoxLayout(tabSimple);
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(6);
        hboxLayout3->setObjectName(QString::fromUtf8("hboxLayout3"));
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        groupFilename = new QGroupBox(tabSimple);
        groupFilename->setObjectName(QString::fromUtf8("groupFilename"));
        gridLayout = new QGridLayout(groupFilename);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        lblSuffix = new QLabel(groupFilename);
        lblSuffix->setObjectName(QString::fromUtf8("lblSuffix"));

        gridLayout->addWidget(lblSuffix, 1, 0, 1, 1);

        buttonHelp4 = new QPushButton(groupFilename);
        buttonHelp4->setObjectName(QString::fromUtf8("buttonHelp4"));
        buttonHelp4->setEnabled(false);

        gridLayout->addWidget(buttonHelp4, 3, 3, 1, 1);

        buttonHelp3 = new QPushButton(groupFilename);
        buttonHelp3->setObjectName(QString::fromUtf8("buttonHelp3"));
        buttonHelp3->setEnabled(false);

        gridLayout->addWidget(buttonHelp3, 2, 3, 1, 1);

        comboFilenameCustom = new ExtHistoryCombo(groupFilename);
        comboFilenameCustom->setObjectName(QString::fromUtf8("comboFilenameCustom"));
        comboFilenameCustom->setEnabled(false);
        QSizePolicy sizePolicy3(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy3.setHorizontalStretch(2);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(comboFilenameCustom->sizePolicy().hasHeightForWidth());
        comboFilenameCustom->setSizePolicy(sizePolicy3);
        comboFilenameCustom->setSizeIncrement(QSize(0, 0));
        comboFilenameCustom->setEditable(true);

        gridLayout->addWidget(comboFilenameCustom, 2, 2, 1, 1);

        comboFilenameSimple = new QComboBox(groupFilename);
        comboFilenameSimple->addItem(QString());
        comboFilenameSimple->addItem(QString());
        comboFilenameSimple->addItem(QString());
        comboFilenameSimple->addItem(QString());
        comboFilenameSimple->addItem(QString());
        comboFilenameSimple->setObjectName(QString::fromUtf8("comboFilenameSimple"));
        QSizePolicy sizePolicy4(QSizePolicy::Maximum, QSizePolicy::Fixed);
        sizePolicy4.setHorizontalStretch(3);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(comboFilenameSimple->sizePolicy().hasHeightForWidth());
        comboFilenameSimple->setSizePolicy(sizePolicy4);

        gridLayout->addWidget(comboFilenameSimple, 2, 1, 1, 1);

        lblFilename = new QLabel(groupFilename);
        lblFilename->setObjectName(QString::fromUtf8("lblFilename"));

        gridLayout->addWidget(lblFilename, 2, 0, 1, 1);

        buttonHelp2 = new QPushButton(groupFilename);
        buttonHelp2->setObjectName(QString::fromUtf8("buttonHelp2"));

        gridLayout->addWidget(buttonHelp2, 1, 3, 1, 1);

        comboSuffixCustom = new ExtHistoryCombo(groupFilename);
        comboSuffixCustom->setObjectName(QString::fromUtf8("comboSuffixCustom"));
        sizePolicy3.setHeightForWidth(comboSuffixCustom->sizePolicy().hasHeightForWidth());
        comboSuffixCustom->setSizePolicy(sizePolicy3);
        comboSuffixCustom->setSizeIncrement(QSize(0, 0));
        comboSuffixCustom->setEditable(true);

        gridLayout->addWidget(comboSuffixCustom, 1, 2, 1, 1);

        comboSuffix = new QComboBox(groupFilename);
        comboSuffix->addItem(QString());
        comboSuffix->addItem(QString());
        comboSuffix->addItem(QString());
        comboSuffix->setObjectName(QString::fromUtf8("comboSuffix"));
        QSizePolicy sizePolicy5(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy5.setHorizontalStretch(3);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(comboSuffix->sizePolicy().hasHeightForWidth());
        comboSuffix->setSizePolicy(sizePolicy5);

        gridLayout->addWidget(comboSuffix, 1, 1, 1, 1);

        buttonHelp1 = new QPushButton(groupFilename);
        buttonHelp1->setObjectName(QString::fromUtf8("buttonHelp1"));

        gridLayout->addWidget(buttonHelp1, 0, 3, 1, 1);

        lblPrefix = new QLabel(groupFilename);
        lblPrefix->setObjectName(QString::fromUtf8("lblPrefix"));

        gridLayout->addWidget(lblPrefix, 0, 0, 1, 1);

        lblExtension_2 = new QLabel(groupFilename);
        lblExtension_2->setObjectName(QString::fromUtf8("lblExtension_2"));

        gridLayout->addWidget(lblExtension_2, 3, 0, 1, 1);

        comboPrefix = new QComboBox(groupFilename);
        comboPrefix->addItem(QString());
        comboPrefix->addItem(QString());
        comboPrefix->addItem(QString());
        comboPrefix->setObjectName(QString::fromUtf8("comboPrefix"));
        sizePolicy5.setHeightForWidth(comboPrefix->sizePolicy().hasHeightForWidth());
        comboPrefix->setSizePolicy(sizePolicy5);

        gridLayout->addWidget(comboPrefix, 0, 1, 1, 1);

        comboExtensionSimple = new QComboBox(groupFilename);
        comboExtensionSimple->addItem(QString());
        comboExtensionSimple->addItem(QString());
        comboExtensionSimple->addItem(QString());
        comboExtensionSimple->addItem(QString());
        comboExtensionSimple->addItem(QString());
        comboExtensionSimple->setObjectName(QString::fromUtf8("comboExtensionSimple"));
        sizePolicy4.setHeightForWidth(comboExtensionSimple->sizePolicy().hasHeightForWidth());
        comboExtensionSimple->setSizePolicy(sizePolicy4);

        gridLayout->addWidget(comboExtensionSimple, 3, 1, 1, 1);

        comboPrefixCustom = new ExtHistoryCombo(groupFilename);
        comboPrefixCustom->setObjectName(QString::fromUtf8("comboPrefixCustom"));
        sizePolicy3.setHeightForWidth(comboPrefixCustom->sizePolicy().hasHeightForWidth());
        comboPrefixCustom->setSizePolicy(sizePolicy3);
        comboPrefixCustom->setSizeIncrement(QSize(0, 0));
        comboPrefixCustom->setEditable(true);

        gridLayout->addWidget(comboPrefixCustom, 0, 2, 1, 1);

        comboExtensionCustom = new ExtHistoryCombo(groupFilename);
        comboExtensionCustom->setObjectName(QString::fromUtf8("comboExtensionCustom"));
        comboExtensionCustom->setEnabled(false);
        sizePolicy3.setHeightForWidth(comboExtensionCustom->sizePolicy().hasHeightForWidth());
        comboExtensionCustom->setSizePolicy(sizePolicy3);
        comboExtensionCustom->setSizeIncrement(QSize(0, 0));
        comboExtensionCustom->setEditable(true);

        gridLayout->addWidget(comboExtensionCustom, 3, 2, 1, 1);


        hboxLayout3->addWidget(groupFilename);

        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setSpacing(6);
        vboxLayout3->setObjectName(QString::fromUtf8("vboxLayout3"));
        vboxLayout3->setContentsMargins(0, 0, 0, 0);
        groupNumber = new QGroupBox(tabSimple);
        groupNumber->setObjectName(QString::fromUtf8("groupNumber"));
        QSizePolicy sizePolicy6(QSizePolicy::Maximum, QSizePolicy::Preferred);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(groupNumber->sizePolicy().hasHeightForWidth());
        groupNumber->setSizePolicy(sizePolicy6);
        gridLayout1 = new QGridLayout(groupNumber);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        spinDigits = new QSpinBox(groupNumber);
        spinDigits->setObjectName(QString::fromUtf8("spinDigits"));
        QSizePolicy sizePolicy7(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy7.setHorizontalStretch(2);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(spinDigits->sizePolicy().hasHeightForWidth());
        spinDigits->setSizePolicy(sizePolicy7);
        spinDigits->setMinimum(1);

        gridLayout1->addWidget(spinDigits, 1, 1, 1, 1);

        spinIndex = new QSpinBox(groupNumber);
        spinIndex->setObjectName(QString::fromUtf8("spinIndex"));
        sizePolicy7.setHeightForWidth(spinIndex->sizePolicy().hasHeightForWidth());
        spinIndex->setSizePolicy(sizePolicy7);
        spinIndex->setMinimum(-10000);
        spinIndex->setMaximum(10000);

        gridLayout1->addWidget(spinIndex, 0, 1, 1, 1);

        lblDigits = new QLabel(groupNumber);
        lblDigits->setObjectName(QString::fromUtf8("lblDigits"));

        gridLayout1->addWidget(lblDigits, 1, 0, 1, 1);

        lblIndex = new QLabel(groupNumber);
        lblIndex->setObjectName(QString::fromUtf8("lblIndex"));

        gridLayout1->addWidget(lblIndex, 0, 0, 1, 1);


        vboxLayout3->addWidget(groupNumber);

        spacerItem3 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Minimum);

        vboxLayout3->addItem(spacerItem3);

        buttonFindSimple = new QPushButton(tabSimple);
        buttonFindSimple->setObjectName(QString::fromUtf8("buttonFindSimple"));
        buttonFindSimple->setEnabled(false);
        QSizePolicy sizePolicy8(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy8.setHorizontalStretch(0);
        sizePolicy8.setVerticalStretch(0);
        sizePolicy8.setHeightForWidth(buttonFindSimple->sizePolicy().hasHeightForWidth());
        buttonFindSimple->setSizePolicy(sizePolicy8);

        vboxLayout3->addWidget(buttonFindSimple);


        hboxLayout3->addLayout(vboxLayout3);


        vboxLayout2->addLayout(hboxLayout3);

        tabWidget->addTab(tabSimple, QString());

        vboxLayout->addWidget(tabWidget);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setSpacing(6);
        hboxLayout4->setObjectName(QString::fromUtf8("hboxLayout4"));
        hboxLayout4->setContentsMargins(0, 0, 0, 0);
        listPreview = new PreviewList(KRenameFilename);
        listPreview->setObjectName(QString::fromUtf8("listPreview"));
        QSizePolicy sizePolicy9(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy9.setHorizontalStretch(0);
        sizePolicy9.setVerticalStretch(0);
        sizePolicy9.setHeightForWidth(listPreview->sizePolicy().hasHeightForWidth());
        listPreview->setSizePolicy(sizePolicy9);
        listPreview->setSizeIncrement(QSize(0, 2));
        listPreview->setRootIsDecorated(false);
        listPreview->setItemsExpandable(false);
        listPreview->setAllColumnsShowFocus(true);

        hboxLayout4->addWidget(listPreview);

        vboxLayout4 = new QVBoxLayout();
        vboxLayout4->setSpacing(6);
        vboxLayout4->setObjectName(QString::fromUtf8("vboxLayout4"));
        vboxLayout4->setContentsMargins(0, 0, 0, 0);
        spacerItem4 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout4->addItem(spacerItem4);

        buttonUp = new QPushButton(KRenameFilename);
        buttonUp->setObjectName(QString::fromUtf8("buttonUp"));

        vboxLayout4->addWidget(buttonUp);

        buttonDown = new QPushButton(KRenameFilename);
        buttonDown->setObjectName(QString::fromUtf8("buttonDown"));

        vboxLayout4->addWidget(buttonDown);

        spacerItem5 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout4->addItem(spacerItem5);


        hboxLayout4->addLayout(vboxLayout4);


        vboxLayout->addLayout(hboxLayout4);

#if QT_CONFIG(shortcut)
        lblTemplate->setBuddy(filenameTemplate);
        lblExtension->setBuddy(comboExtension);
        lblSuffix->setBuddy(comboSuffixCustom);
        lblFilename->setBuddy(comboFilenameCustom);
        lblPrefix->setBuddy(comboPrefixCustom);
        lblExtension_2->setBuddy(comboExtensionCustom);
        lblDigits->setBuddy(spinDigits);
        lblIndex->setBuddy(spinIndex);
#endif // QT_CONFIG(shortcut)

        retranslateUi(KRenameFilename);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(KRenameFilename);
    } // setupUi

    void retranslateUi(QWidget *KRenameFilename)
    {
        lblTemplate->setText(tr2i18n("&Template:", nullptr));
        filenameTemplate->setItemText(0, tr2i18n("$", nullptr));

#if QT_CONFIG(tooltip)
        filenameTemplate->setToolTip(tr2i18n("<qt>Enter a template for changing the filename.</qt>", nullptr));
#endif // QT_CONFIG(tooltip)
        lblDot->setText(tr2i18n("<p><b>.</b></p>", nullptr));
        extensionTemplate->setItemText(0, tr2i18n("$", nullptr));

#if QT_CONFIG(tooltip)
        extensionTemplate->setToolTip(tr2i18n("<qt>Enter a template for changing the file extension.</qt>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        buttonFunctions->setToolTip(tr2i18n("<qt>Insert special functions like the artist of an mp3 or the creation date of an image.</qt>", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonFunctions->setText(tr2i18n("&Functions...", nullptr));
#if QT_CONFIG(tooltip)
        checkExtension->setToolTip(tr2i18n("<qt>Keep the file extension as it is and do not change it.</qt>", nullptr));
#endif // QT_CONFIG(tooltip)
        checkExtension->setText(tr2i18n("&Use extension of the input file", nullptr));
        lblExtension->setText(tr2i18n("F&ile extension starts at:", nullptr));
        comboExtension->setItemText(0, tr2i18n("First Dot", nullptr));
        comboExtension->setItemText(1, tr2i18n("Last Dot", nullptr));
        comboExtension->setItemText(2, tr2i18n("No File Extension", nullptr));

#if QT_CONFIG(tooltip)
        comboExtension->setToolTip(tr2i18n("<qt>Configure which part of the filename is considered to be the fileextension. E.g. \"First Dot\", will consider \".tar.gz\" as extension, \"Last Dot\" only \".gz\".</qt>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        buttonFind->setToolTip(tr2i18n("<qt>Find and replace strings and regular expressions in the renamed filename.</qt>", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonFind->setText(tr2i18n("Find &and Replace...", nullptr));
#if QT_CONFIG(tooltip)
        buttonNumbering->setToolTip(tr2i18n("<qt>Configure start index, stepping and skipping for numbering of filenames.</qt>", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonNumbering->setText(tr2i18n("&Numbering...", nullptr));
#if QT_CONFIG(tooltip)
        buttonInsert->setToolTip(tr2i18n("<qt>Graphically select a part of a filename to insert.</qt>", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonInsert->setText(tr2i18n("&Insert Part of Filename...", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabAdvanced), tr2i18n("&Advanced Filename", nullptr));
        groupFilename->setTitle(tr2i18n("&Filename", nullptr));
        lblSuffix->setText(tr2i18n("&Suffix:", nullptr));
#if QT_CONFIG(tooltip)
        buttonHelp4->setToolTip(tr2i18n("<qt>Insert special functions like the artist of an mp3 or the creation date of an image.</qt>", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonHelp4->setText(QString());
#if QT_CONFIG(tooltip)
        buttonHelp3->setToolTip(tr2i18n("<qt>Insert special functions like the artist of an mp3 or the creation date of an image.</qt>", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonHelp3->setText(QString());
        comboFilenameSimple->setItemText(0, tr2i18n("Use original name", nullptr));
        comboFilenameSimple->setItemText(1, tr2i18n("Convert to lower case", nullptr));
        comboFilenameSimple->setItemText(2, tr2i18n("Convert to upper case", nullptr));
        comboFilenameSimple->setItemText(3, tr2i18n("Capitalize", nullptr));
        comboFilenameSimple->setItemText(4, tr2i18n("Custom name", nullptr));

        lblFilename->setText(tr2i18n("File&name:", nullptr));
#if QT_CONFIG(tooltip)
        buttonHelp2->setToolTip(tr2i18n("<qt>Insert special functions like the artist of an mp3 or the creation date of an image.</qt>", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonHelp2->setText(QString());
        comboSuffix->setItemText(0, QString());
        comboSuffix->setItemText(1, tr2i18n("Number", nullptr));
        comboSuffix->setItemText(2, tr2i18n("Date", nullptr));

#if QT_CONFIG(tooltip)
        buttonHelp1->setToolTip(tr2i18n("<qt>Insert special functions like the artist of an mp3 or the creation date of an image.</qt>", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonHelp1->setText(QString());
        lblPrefix->setText(tr2i18n("&Prefix:", nullptr));
        lblExtension_2->setText(tr2i18n("&Extension:", nullptr));
        comboPrefix->setItemText(0, QString());
        comboPrefix->setItemText(1, tr2i18n("Number", nullptr));
        comboPrefix->setItemText(2, tr2i18n("Date", nullptr));

        comboExtensionSimple->setItemText(0, tr2i18n("Use original extension", nullptr));
        comboExtensionSimple->setItemText(1, tr2i18n("Convert to lower case", nullptr));
        comboExtensionSimple->setItemText(2, tr2i18n("Convert to upper case", nullptr));
        comboExtensionSimple->setItemText(3, tr2i18n("Capitalize", nullptr));
        comboExtensionSimple->setItemText(4, tr2i18n("Custom extension", nullptr));

        groupNumber->setTitle(tr2i18n("N&umber", nullptr));
        lblDigits->setText(tr2i18n("Number of &digits:", nullptr));
        lblIndex->setText(tr2i18n("Start  &index:", nullptr));
#if QT_CONFIG(tooltip)
        buttonFindSimple->setToolTip(tr2i18n("<qt>Find and replace strings and regular expressions in the renamed filename.</qt>", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonFindSimple->setText(tr2i18n("Find &and Replace...", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabSimple), tr2i18n("&Simple Filename", nullptr));
#if QT_CONFIG(tooltip)
        buttonUp->setToolTip(tr2i18n("Move selected files upwards.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonUp->setText(tr2i18n("&Up", nullptr));
#if QT_CONFIG(tooltip)
        buttonDown->setToolTip(tr2i18n("Move selected files downwards.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonDown->setText(tr2i18n("&Down", nullptr));
        (void)KRenameFilename;
    } // retranslateUi

};

namespace Ui {
    class KRenameFilename: public Ui_KRenameFilename {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KRENAMEFILENAME_H

