#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'tokensortmodedialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TOKENSORTMODEDIALOG_H
#define UI_TOKENSORTMODEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_TokenSortModeDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QRadioButton *radioAscending;
    QRadioButton *radioDescending;
    QRadioButton *radioNumeric;
    QLabel *label;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_3;
    QRadioButton *radioPredefined;
    QComboBox *comboPredefined;
    QRadioButton *radioCustom;
    QComboBox *comboToken;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *TokenSortModeDialog)
    {
        if (TokenSortModeDialog->objectName().isEmpty())
            TokenSortModeDialog->setObjectName(QString::fromUtf8("TokenSortModeDialog"));
        TokenSortModeDialog->resize(413, 189);
        verticalLayout_2 = new QVBoxLayout(TokenSortModeDialog);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        groupBox = new QGroupBox(TokenSortModeDialog);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        radioAscending = new QRadioButton(groupBox);
        radioAscending->setObjectName(QString::fromUtf8("radioAscending"));
        radioAscending->setChecked(true);

        verticalLayout->addWidget(radioAscending);

        radioDescending = new QRadioButton(groupBox);
        radioDescending->setObjectName(QString::fromUtf8("radioDescending"));

        verticalLayout->addWidget(radioDescending);

        radioNumeric = new QRadioButton(groupBox);
        radioNumeric->setObjectName(QString::fromUtf8("radioNumeric"));

        verticalLayout->addWidget(radioNumeric);


        horizontalLayout->addWidget(groupBox);

        label = new QLabel(TokenSortModeDialog);
        label->setObjectName(QString::fromUtf8("label"));
        QSizePolicy sizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(label);

        groupBox_2 = new QGroupBox(TokenSortModeDialog);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        verticalLayout_3 = new QVBoxLayout(groupBox_2);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        radioPredefined = new QRadioButton(groupBox_2);
        radioPredefined->setObjectName(QString::fromUtf8("radioPredefined"));
        radioPredefined->setChecked(true);

        verticalLayout_3->addWidget(radioPredefined);

        comboPredefined = new QComboBox(groupBox_2);
        comboPredefined->setObjectName(QString::fromUtf8("comboPredefined"));

        verticalLayout_3->addWidget(comboPredefined);

        radioCustom = new QRadioButton(groupBox_2);
        radioCustom->setObjectName(QString::fromUtf8("radioCustom"));

        verticalLayout_3->addWidget(radioCustom);

        comboToken = new QComboBox(groupBox_2);
        comboToken->setObjectName(QString::fromUtf8("comboToken"));
        comboToken->setEditable(true);

        verticalLayout_3->addWidget(comboToken);


        horizontalLayout->addWidget(groupBox_2);


        verticalLayout_2->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 4, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(TokenSortModeDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(TokenSortModeDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), TokenSortModeDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), TokenSortModeDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(TokenSortModeDialog);
    } // setupUi

    void retranslateUi(QDialog *TokenSortModeDialog)
    {
        TokenSortModeDialog->setWindowTitle(tr2i18n("Custom Sorting", nullptr));
        groupBox->setTitle(tr2i18n("&Sort filenames ...", nullptr));
        radioAscending->setText(tr2i18n("&Ascending", nullptr));
        radioDescending->setText(tr2i18n("&Descending", nullptr));
        radioNumeric->setText(tr2i18n("&Numeric", nullptr));
        label->setText(tr2i18n("by", nullptr));
        groupBox_2->setTitle(tr2i18n("&Token ...", nullptr));
        radioPredefined->setText(tr2i18n("&Predefined", nullptr));
        radioCustom->setText(tr2i18n("&Custom", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TokenSortModeDialog: public Ui_TokenSortModeDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TOKENSORTMODEDIALOG_H

