#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'replaceitemdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_REPLACEITEMDLG_H
#define UI_REPLACEITEMDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ReplaceItemDlg
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    QLineEdit *lineFind;
    QLabel *label_2;
    QLineEdit *lineReplace;
    QCheckBox *checkRegular;
    QCheckBox *checkProcess;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ReplaceItemDlg)
    {
        if (ReplaceItemDlg->objectName().isEmpty())
            ReplaceItemDlg->setObjectName(QString::fromUtf8("ReplaceItemDlg"));
        ReplaceItemDlg->resize(393, 145);
        vboxLayout = new QVBoxLayout(ReplaceItemDlg);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label = new QLabel(ReplaceItemDlg);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        lineFind = new QLineEdit(ReplaceItemDlg);
        lineFind->setObjectName(QString::fromUtf8("lineFind"));

        gridLayout->addWidget(lineFind, 0, 1, 1, 1);

        label_2 = new QLabel(ReplaceItemDlg);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        lineReplace = new QLineEdit(ReplaceItemDlg);
        lineReplace->setObjectName(QString::fromUtf8("lineReplace"));

        gridLayout->addWidget(lineReplace, 1, 1, 1, 1);


        vboxLayout->addLayout(gridLayout);

        checkRegular = new QCheckBox(ReplaceItemDlg);
        checkRegular->setObjectName(QString::fromUtf8("checkRegular"));

        vboxLayout->addWidget(checkRegular);

        checkProcess = new QCheckBox(ReplaceItemDlg);
        checkProcess->setObjectName(QString::fromUtf8("checkProcess"));

        vboxLayout->addWidget(checkProcess);

        buttonBox = new QDialogButtonBox(ReplaceItemDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        vboxLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label->setBuddy(lineFind);
        label_2->setBuddy(lineReplace);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ReplaceItemDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), ReplaceItemDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), ReplaceItemDlg, SLOT(reject()));

        QMetaObject::connectSlotsByName(ReplaceItemDlg);
    } // setupUi

    void retranslateUi(QDialog *ReplaceItemDlg)
    {
        ReplaceItemDlg->setWindowTitle(tr2i18n("Find and Replace", nullptr));
        label->setText(tr2i18n("&Find:", nullptr));
        label_2->setText(tr2i18n("&Replace With:", nullptr));
        checkRegular->setText(tr2i18n("Find is a Regular &Expression", nullptr));
        checkProcess->setText(tr2i18n("&Process tokens in replace string", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ReplaceItemDlg: public Ui_ReplaceItemDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // REPLACEITEMDLG_H

