/****************************************************************************
** Meta object code from reading C++ file 'krenamewindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../krename-5.0.2/src/krenamewindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'krenamewindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KRenameWindow_t {
    QByteArrayData data[62];
    char stringdata0[1003];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KRenameWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KRenameWindow_t qt_meta_stringdata_KRenameWindow = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KRenameWindow"
QT_MOC_LITERAL(1, 14, 11), // "updateCount"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 17), // "renameModeChanged"
QT_MOC_LITERAL(4, 45, 11), // "ERenameMode"
QT_MOC_LITERAL(5, 57, 4), // "mode"
QT_MOC_LITERAL(6, 62, 21), // "overwriteFilesChanged"
QT_MOC_LITERAL(7, 84, 9), // "overwrite"
QT_MOC_LITERAL(8, 94, 23), // "filenameTemplateChanged"
QT_MOC_LITERAL(9, 118, 8), // "filename"
QT_MOC_LITERAL(10, 127, 24), // "extensionTemplateChanged"
QT_MOC_LITERAL(11, 152, 9), // "extension"
QT_MOC_LITERAL(12, 162, 25), // "extensionSplitModeChanged"
QT_MOC_LITERAL(13, 188, 10), // "ESplitMode"
QT_MOC_LITERAL(14, 199, 9), // "splitMode"
QT_MOC_LITERAL(15, 209, 3), // "dot"
QT_MOC_LITERAL(16, 213, 17), // "startIndexChanged"
QT_MOC_LITERAL(17, 231, 5), // "index"
QT_MOC_LITERAL(18, 237, 18), // "filePreviewChanged"
QT_MOC_LITERAL(19, 256, 6), // "enable"
QT_MOC_LITERAL(20, 263, 9), // "filenames"
QT_MOC_LITERAL(21, 273, 13), // "updatePreview"
QT_MOC_LITERAL(22, 287, 27), // "showAdvancedNumberingDialog"
QT_MOC_LITERAL(23, 315, 28), // "showInsertPartFilenameDialog"
QT_MOC_LITERAL(24, 344, 21), // "showFindReplaceDialog"
QT_MOC_LITERAL(25, 366, 8), // "addFiles"
QT_MOC_LITERAL(26, 375, 14), // "removeAllFiles"
QT_MOC_LITERAL(27, 390, 11), // "removeFiles"
QT_MOC_LITERAL(28, 402, 19), // "showTokenHelpDialog"
QT_MOC_LITERAL(29, 422, 10), // "QLineEdit*"
QT_MOC_LITERAL(30, 433, 4), // "edit"
QT_MOC_LITERAL(31, 438, 8), // "accepted"
QT_MOC_LITERAL(32, 447, 18), // "slotEnableControls"
QT_MOC_LITERAL(33, 466, 8), // "slotBack"
QT_MOC_LITERAL(34, 475, 8), // "slotNext"
QT_MOC_LITERAL(35, 484, 10), // "slotFinish"
QT_MOC_LITERAL(36, 495, 8), // "showPage"
QT_MOC_LITERAL(37, 504, 21), // "slotRenameModeChanged"
QT_MOC_LITERAL(38, 526, 19), // "slotTemplateChanged"
QT_MOC_LITERAL(39, 546, 25), // "slotSimpleTemplateChanged"
QT_MOC_LITERAL(40, 572, 22), // "slotTokenHelpRequested"
QT_MOC_LITERAL(41, 595, 29), // "slotTokenHelpRequestedWizard1"
QT_MOC_LITERAL(42, 625, 29), // "slotTokenHelpRequestedWizard2"
QT_MOC_LITERAL(43, 655, 29), // "slotTokenHelpRequestedWizard3"
QT_MOC_LITERAL(44, 685, 29), // "slotTokenHelpRequestedWizard4"
QT_MOC_LITERAL(45, 715, 29), // "slotExtensionSplitModeChanged"
QT_MOC_LITERAL(46, 745, 18), // "slotPreviewChanged"
QT_MOC_LITERAL(47, 764, 15), // "slotSortChanged"
QT_MOC_LITERAL(48, 780, 18), // "slotMaxDotsChanged"
QT_MOC_LITERAL(49, 799, 4), // "dots"
QT_MOC_LITERAL(50, 804, 12), // "slotOpenFile"
QT_MOC_LITERAL(51, 817, 11), // "QModelIndex"
QT_MOC_LITERAL(52, 829, 10), // "slotMoveUp"
QT_MOC_LITERAL(53, 840, 12), // "slotMoveDown"
QT_MOC_LITERAL(54, 853, 17), // "slotMoveUpPreview"
QT_MOC_LITERAL(55, 871, 19), // "slotMoveDownPreview"
QT_MOC_LITERAL(56, 891, 17), // "slotPluginChanged"
QT_MOC_LITERAL(57, 909, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(58, 926, 8), // "selected"
QT_MOC_LITERAL(59, 935, 17), // "slotPluginEnabled"
QT_MOC_LITERAL(60, 953, 27), // "slotSimpleStartIndexChanged"
QT_MOC_LITERAL(61, 981, 21) // "slotGotoTemplatesPage"

    },
    "KRenameWindow\0updateCount\0\0renameModeChanged\0"
    "ERenameMode\0mode\0overwriteFilesChanged\0"
    "overwrite\0filenameTemplateChanged\0"
    "filename\0extensionTemplateChanged\0"
    "extension\0extensionSplitModeChanged\0"
    "ESplitMode\0splitMode\0dot\0startIndexChanged\0"
    "index\0filePreviewChanged\0enable\0"
    "filenames\0updatePreview\0"
    "showAdvancedNumberingDialog\0"
    "showInsertPartFilenameDialog\0"
    "showFindReplaceDialog\0addFiles\0"
    "removeAllFiles\0removeFiles\0"
    "showTokenHelpDialog\0QLineEdit*\0edit\0"
    "accepted\0slotEnableControls\0slotBack\0"
    "slotNext\0slotFinish\0showPage\0"
    "slotRenameModeChanged\0slotTemplateChanged\0"
    "slotSimpleTemplateChanged\0"
    "slotTokenHelpRequested\0"
    "slotTokenHelpRequestedWizard1\0"
    "slotTokenHelpRequestedWizard2\0"
    "slotTokenHelpRequestedWizard3\0"
    "slotTokenHelpRequestedWizard4\0"
    "slotExtensionSplitModeChanged\0"
    "slotPreviewChanged\0slotSortChanged\0"
    "slotMaxDotsChanged\0dots\0slotOpenFile\0"
    "QModelIndex\0slotMoveUp\0slotMoveDown\0"
    "slotMoveUpPreview\0slotMoveDownPreview\0"
    "slotPluginChanged\0QTreeWidgetItem*\0"
    "selected\0slotPluginEnabled\0"
    "slotSimpleStartIndexChanged\0"
    "slotGotoTemplatesPage"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KRenameWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      43,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      17,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  229,    2, 0x06 /* Public */,
       3,    1,  230,    2, 0x06 /* Public */,
       6,    1,  233,    2, 0x06 /* Public */,
       8,    1,  236,    2, 0x06 /* Public */,
      10,    1,  239,    2, 0x06 /* Public */,
      12,    2,  242,    2, 0x06 /* Public */,
      16,    1,  247,    2, 0x06 /* Public */,
      18,    2,  250,    2, 0x06 /* Public */,
      21,    0,  255,    2, 0x06 /* Public */,
      22,    0,  256,    2, 0x06 /* Public */,
      23,    0,  257,    2, 0x06 /* Public */,
      24,    0,  258,    2, 0x06 /* Public */,
      25,    0,  259,    2, 0x06 /* Public */,
      26,    0,  260,    2, 0x06 /* Public */,
      27,    0,  261,    2, 0x06 /* Public */,
      28,    1,  262,    2, 0x06 /* Public */,
      31,    0,  265,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      32,    0,  266,    2, 0x0a /* Public */,
      33,    0,  267,    2, 0x08 /* Private */,
      34,    0,  268,    2, 0x08 /* Private */,
      35,    0,  269,    2, 0x08 /* Private */,
      36,    1,  270,    2, 0x08 /* Private */,
      37,    0,  273,    2, 0x08 /* Private */,
      38,    0,  274,    2, 0x08 /* Private */,
      39,    0,  275,    2, 0x08 /* Private */,
      40,    0,  276,    2, 0x08 /* Private */,
      41,    0,  277,    2, 0x08 /* Private */,
      42,    0,  278,    2, 0x08 /* Private */,
      43,    0,  279,    2, 0x08 /* Private */,
      44,    0,  280,    2, 0x08 /* Private */,
      45,    1,  281,    2, 0x08 /* Private */,
      46,    0,  284,    2, 0x08 /* Private */,
      47,    1,  285,    2, 0x08 /* Private */,
      48,    1,  288,    2, 0x08 /* Private */,
      50,    1,  291,    2, 0x08 /* Private */,
      52,    0,  294,    2, 0x08 /* Private */,
      53,    0,  295,    2, 0x08 /* Private */,
      54,    0,  296,    2, 0x08 /* Private */,
      55,    0,  297,    2, 0x08 /* Private */,
      56,    1,  298,    2, 0x08 /* Private */,
      59,    0,  301,    2, 0x08 /* Private */,
      60,    0,  302,    2, 0x08 /* Private */,
      61,    0,  303,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, 0x80000000 | 13, QMetaType::Int,   14,   15,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::Bool, QMetaType::Bool,   19,   20,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 29,   30,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::Int,   49,
    QMetaType::Void, 0x80000000 | 51,   17,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 57,   58,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KRenameWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<KRenameWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->updateCount(); break;
        case 1: _t->renameModeChanged((*reinterpret_cast< ERenameMode(*)>(_a[1]))); break;
        case 2: _t->overwriteFilesChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->filenameTemplateChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->extensionTemplateChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->extensionSplitModeChanged((*reinterpret_cast< ESplitMode(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 6: _t->startIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->filePreviewChanged((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 8: _t->updatePreview(); break;
        case 9: _t->showAdvancedNumberingDialog(); break;
        case 10: _t->showInsertPartFilenameDialog(); break;
        case 11: _t->showFindReplaceDialog(); break;
        case 12: _t->addFiles(); break;
        case 13: _t->removeAllFiles(); break;
        case 14: _t->removeFiles(); break;
        case 15: _t->showTokenHelpDialog((*reinterpret_cast< QLineEdit*(*)>(_a[1]))); break;
        case 16: _t->accepted(); break;
        case 17: _t->slotEnableControls(); break;
        case 18: _t->slotBack(); break;
        case 19: _t->slotNext(); break;
        case 20: _t->slotFinish(); break;
        case 21: _t->showPage((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->slotRenameModeChanged(); break;
        case 23: _t->slotTemplateChanged(); break;
        case 24: _t->slotSimpleTemplateChanged(); break;
        case 25: _t->slotTokenHelpRequested(); break;
        case 26: _t->slotTokenHelpRequestedWizard1(); break;
        case 27: _t->slotTokenHelpRequestedWizard2(); break;
        case 28: _t->slotTokenHelpRequestedWizard3(); break;
        case 29: _t->slotTokenHelpRequestedWizard4(); break;
        case 30: _t->slotExtensionSplitModeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 31: _t->slotPreviewChanged(); break;
        case 32: _t->slotSortChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 33: _t->slotMaxDotsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 34: _t->slotOpenFile((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 35: _t->slotMoveUp(); break;
        case 36: _t->slotMoveDown(); break;
        case 37: _t->slotMoveUpPreview(); break;
        case 38: _t->slotMoveDownPreview(); break;
        case 39: _t->slotPluginChanged((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 40: _t->slotPluginEnabled(); break;
        case 41: _t->slotSimpleStartIndexChanged(); break;
        case 42: _t->slotGotoTemplatesPage(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QLineEdit* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (KRenameWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::updateCount)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (KRenameWindow::*)(ERenameMode );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::renameModeChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (KRenameWindow::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::overwriteFilesChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (KRenameWindow::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::filenameTemplateChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (KRenameWindow::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::extensionTemplateChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (KRenameWindow::*)(ESplitMode , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::extensionSplitModeChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (KRenameWindow::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::startIndexChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (KRenameWindow::*)(bool , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::filePreviewChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (KRenameWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::updatePreview)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (KRenameWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::showAdvancedNumberingDialog)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (KRenameWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::showInsertPartFilenameDialog)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (KRenameWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::showFindReplaceDialog)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (KRenameWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::addFiles)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (KRenameWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::removeAllFiles)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (KRenameWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::removeFiles)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (KRenameWindow::*)(QLineEdit * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::showTokenHelpDialog)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (KRenameWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KRenameWindow::accepted)) {
                *result = 16;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KRenameWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KMainWindow::staticMetaObject>(),
    qt_meta_stringdata_KRenameWindow.data,
    qt_meta_data_KRenameWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KRenameWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KRenameWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KRenameWindow.stringdata0))
        return static_cast<void*>(this);
    return KMainWindow::qt_metacast(_clname);
}

int KRenameWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    return _id;
}

// SIGNAL 0
void KRenameWindow::updateCount()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KRenameWindow::renameModeChanged(ERenameMode _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KRenameWindow::overwriteFilesChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KRenameWindow::filenameTemplateChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KRenameWindow::extensionTemplateChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KRenameWindow::extensionSplitModeChanged(ESplitMode _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KRenameWindow::startIndexChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KRenameWindow::filePreviewChanged(bool _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void KRenameWindow::updatePreview()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KRenameWindow::showAdvancedNumberingDialog()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KRenameWindow::showInsertPartFilenameDialog()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KRenameWindow::showFindReplaceDialog()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void KRenameWindow::addFiles()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void KRenameWindow::removeAllFiles()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void KRenameWindow::removeFiles()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void KRenameWindow::showTokenHelpDialog(QLineEdit * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void KRenameWindow::accepted()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
