/****************************************************************************
** Meta object code from reading C++ file 'modeltest.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../krename-5.0.2/src/modeltest.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'modeltest.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ModelTest_t {
    QByteArrayData data[17];
    char stringdata0[185];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ModelTest_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ModelTest_t qt_meta_stringdata_ModelTest = {
    {
QT_MOC_LITERAL(0, 0, 9), // "ModelTest"
QT_MOC_LITERAL(1, 10, 23), // "nonDestructiveBasicTest"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 8), // "rowCount"
QT_MOC_LITERAL(4, 44, 11), // "columnCount"
QT_MOC_LITERAL(5, 56, 8), // "hasIndex"
QT_MOC_LITERAL(6, 65, 5), // "index"
QT_MOC_LITERAL(7, 71, 6), // "parent"
QT_MOC_LITERAL(8, 78, 4), // "data"
QT_MOC_LITERAL(9, 83, 11), // "runAllTests"
QT_MOC_LITERAL(10, 95, 21), // "rowsAboutToBeInserted"
QT_MOC_LITERAL(11, 117, 11), // "QModelIndex"
QT_MOC_LITERAL(12, 129, 5), // "start"
QT_MOC_LITERAL(13, 135, 3), // "end"
QT_MOC_LITERAL(14, 139, 12), // "rowsInserted"
QT_MOC_LITERAL(15, 152, 20), // "rowsAboutToBeRemoved"
QT_MOC_LITERAL(16, 173, 11) // "rowsRemoved"

    },
    "ModelTest\0nonDestructiveBasicTest\0\0"
    "rowCount\0columnCount\0hasIndex\0index\0"
    "parent\0data\0runAllTests\0rowsAboutToBeInserted\0"
    "QModelIndex\0start\0end\0rowsInserted\0"
    "rowsAboutToBeRemoved\0rowsRemoved"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ModelTest[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x08 /* Private */,
       3,    0,   75,    2, 0x08 /* Private */,
       4,    0,   76,    2, 0x08 /* Private */,
       5,    0,   77,    2, 0x08 /* Private */,
       6,    0,   78,    2, 0x08 /* Private */,
       7,    0,   79,    2, 0x08 /* Private */,
       8,    0,   80,    2, 0x08 /* Private */,
       9,    0,   81,    2, 0x09 /* Protected */,
      10,    3,   82,    2, 0x09 /* Protected */,
      14,    3,   89,    2, 0x09 /* Protected */,
      15,    3,   96,    2, 0x09 /* Protected */,
      16,    3,  103,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11, QMetaType::Int, QMetaType::Int,    7,   12,   13,
    QMetaType::Void, 0x80000000 | 11, QMetaType::Int, QMetaType::Int,    7,   12,   13,
    QMetaType::Void, 0x80000000 | 11, QMetaType::Int, QMetaType::Int,    7,   12,   13,
    QMetaType::Void, 0x80000000 | 11, QMetaType::Int, QMetaType::Int,    7,   12,   13,

       0        // eod
};

void ModelTest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ModelTest *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->nonDestructiveBasicTest(); break;
        case 1: _t->rowCount(); break;
        case 2: _t->columnCount(); break;
        case 3: _t->hasIndex(); break;
        case 4: _t->index(); break;
        case 5: _t->parent(); break;
        case 6: _t->data(); break;
        case 7: _t->runAllTests(); break;
        case 8: _t->rowsAboutToBeInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 9: _t->rowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 10: _t->rowsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 11: _t->rowsRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ModelTest::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_ModelTest.data,
    qt_meta_data_ModelTest,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ModelTest::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ModelTest::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ModelTest.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ModelTest::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
