#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'progressdialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROGRESSDIALOG_H
#define UI_PROGRESSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ProgressDialog
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QProgressBar *bar;
    QPushButton *buttonCancel;
    QListWidget *display;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ProgressDialog)
    {
        if (ProgressDialog->objectName().isEmpty())
            ProgressDialog->setObjectName(QString::fromUtf8("ProgressDialog"));
        ProgressDialog->resize(400, 300);
        vboxLayout = new QVBoxLayout(ProgressDialog);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        bar = new QProgressBar(ProgressDialog);
        bar->setObjectName(QString::fromUtf8("bar"));
        bar->setValue(24);

        hboxLayout->addWidget(bar);

        buttonCancel = new QPushButton(ProgressDialog);
        buttonCancel->setObjectName(QString::fromUtf8("buttonCancel"));

        hboxLayout->addWidget(buttonCancel);


        vboxLayout->addLayout(hboxLayout);

        display = new QListWidget(ProgressDialog);
        display->setObjectName(QString::fromUtf8("display"));

        vboxLayout->addWidget(display);

        buttonBox = new QDialogButtonBox(ProgressDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);
        buttonBox->setCenterButtons(true);

        vboxLayout->addWidget(buttonBox);


        retranslateUi(ProgressDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), ProgressDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), ProgressDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(ProgressDialog);
    } // setupUi

    void retranslateUi(QDialog *ProgressDialog)
    {
        ProgressDialog->setWindowTitle(tr2i18n("Progress", nullptr));
        buttonCancel->setText(tr2i18n("&Cancel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ProgressDialog: public Ui_ProgressDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROGRESSDIALOG_H

