#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'scriptplugindialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCRIPTPLUGINDIALOG_H
#define UI_SCRIPTPLUGINDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ScriptPluginDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    QLineEdit *lineName;
    QLabel *label_2;
    QLineEdit *lineValue;
    QLabel *label_3;
    QComboBox *comboType;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ScriptPluginDialog)
    {
        if (ScriptPluginDialog->objectName().isEmpty())
            ScriptPluginDialog->setObjectName(QString::fromUtf8("ScriptPluginDialog"));
        ScriptPluginDialog->resize(253, 151);
        QSizePolicy sizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ScriptPluginDialog->sizePolicy().hasHeightForWidth());
        ScriptPluginDialog->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(ScriptPluginDialog);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label = new QLabel(ScriptPluginDialog);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        lineName = new QLineEdit(ScriptPluginDialog);
        lineName->setObjectName(QString::fromUtf8("lineName"));

        gridLayout->addWidget(lineName, 0, 1, 1, 1);

        label_2 = new QLabel(ScriptPluginDialog);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        lineValue = new QLineEdit(ScriptPluginDialog);
        lineValue->setObjectName(QString::fromUtf8("lineValue"));

        gridLayout->addWidget(lineValue, 1, 1, 1, 1);

        label_3 = new QLabel(ScriptPluginDialog);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        comboType = new QComboBox(ScriptPluginDialog);
        comboType->setObjectName(QString::fromUtf8("comboType"));
        comboType->setEditable(false);

        gridLayout->addWidget(comboType, 2, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        buttonBox = new QDialogButtonBox(ScriptPluginDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label->setBuddy(lineName);
        label_2->setBuddy(lineValue);
        label_3->setBuddy(comboType);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ScriptPluginDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), ScriptPluginDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), ScriptPluginDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(ScriptPluginDialog);
    } // setupUi

    void retranslateUi(QDialog *ScriptPluginDialog)
    {
        ScriptPluginDialog->setWindowTitle(tr2i18n("Create Variable", nullptr));
        label->setText(tr2i18n("&Name:", nullptr));
        label_2->setText(tr2i18n("&Initial Value:", nullptr));
        label_3->setText(tr2i18n("&Type:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ScriptPluginDialog: public Ui_ScriptPluginDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCRIPTPLUGINDIALOG_H

